@@ -37,7 +37,7 @@ use Carp;
 
 @ISA = qw(Exporter);
 @EXPORT = qw(shell);
-$VERSION = substr(q$Revision: 10.6 $, 10)+0;
+$VERSION = substr(q$Revision: 10.10 $, 10)+0;
 
 my $warning = <<'EOM';
 
@@ -117,7 +117,7 @@ sub load_plugins {
     my ($sh) = @_;
     my @pi;
     foreach my $where (qw(DBI/Shell DBI_Shell)) {
-	my $mod = $where; $mod =~ s!/!::!g;
+	my $mod = $where; $mod =~ s!/!::!g; #/ so vim see the syn correctly
 	my @dir = map { -d "$_/$where" ? ("$_/$where") : () } @INC;
 	foreach my $dir (@dir) {
 	    opendir DIR, $dir or warn "Unable to read $dir: $!\n";
@@ -157,6 +157,7 @@ sub new {
 	 [ 'editor|ed=s'	=> ($ENV{VISUAL} || $ENV{EDITOR} || 'vi') ],
 	 [ 'batch'		=> 0 ],
 	 [ 'displaymode|display'=> 'neat' ],
+	 [ 'columnseparator=s' => ',' ],
 	# defaults for each new database connect:
 	 [ 'init_trace|trace=i' => 0 ],
 	 [ 'init_autocommit|autocommit=i' => 1 ],
@@ -248,6 +249,9 @@ sub new {
     'option' => {
 	    hint => "display or set an option value",
     },
+    'describe' => {
+	    hint => "display information about a table",
+    },
 
     };
 
@@ -330,7 +334,7 @@ sub run {
     $sh->log($warning) unless $sh->{batch};
 
     # Use valid "dbi:driver:..." to connect with source.
-    $sh->do_connect( $sh->{data_source}, $sh->{user}, $sh->{password});
+    $sh->do_connect( $sh->{data_source} );
 
     #
     # Main loop
@@ -345,7 +349,7 @@ sub run {
 	my $prefix = $sh->{command_prefix};
 
 	$current_line = $sh->readline($sh->prompt());
-	$current_line = "/quit" unless defined $current_line;
+	$current_line = "${prefix}quit" unless defined $current_line;
 
 	if ( $current_line =~ /
 		^(.*?)
@@ -369,7 +373,7 @@ sub run {
 		$command = $sh->{abbrev}->{$cmd};
 	    }
 	    else {
-		$command = ($sh->{command}->{$cmd}) ? $cmd : undef;
+		$command = ($sh->{commands}->{$cmd}) ? $cmd : undef;
 	    }
 	    if ($command) {
 		$sh->run_command($command, $output, @args);
@@ -583,6 +587,7 @@ sub do_help {
 sub do_format {
     my ($sh, @args) = @_;
     my $mode = $args[0] || '';
+    my $col_sep = $args[1];
     my $class = eval { DBI::Format->formatter($mode) };
     unless ($class) {
 	$sh->alert("Unable to select '$mode': $@");
@@ -590,6 +595,7 @@ sub do_format {
     }
     $sh->log("Using formatter class '$class'") if $sh->{debug};
     $sh->{display} = $class->new($sh);
+    $sh->do_option("columnseparator=$col_sep") if $col_sep;
 }
 
 
@@ -662,7 +668,7 @@ sub sth_go {
     my @rtail;
     my $i = 0;
     my $display = $sh->{display} || die "panic: no display set";
-    $display->header($sth, \*STDOUT);
+    $display->header($sth, \*STDOUT, $sh->{columnseparator});
     while (my $rowref = $sth->fetchrow_arrayref()) {
 	$i++;
 
@@ -723,14 +729,19 @@ sub do_disconnect {
 
 
 sub do_connect {
-    my ($sh, $dsn, @args) = @_;
+    my ($sh, $dsn, $user, $pass) = @_;
 
-    $dsn = $sh->get_data_source($dsn, @args);
+    $dsn = $sh->get_data_source($dsn);
     return unless $dsn;
 
     $sh->do_disconnect if $sh->{dbh};
 
     $sh->{data_source} = $dsn;
+    if (defined $user and length $user) {
+	$sh->{user}     = $user;
+	$sh->{password} = undef;	# force prompt below
+    }
+
     $sh->log("Connecting to '$sh->{data_source}' as '$sh->{user}'...");
     if ($sh->{user} and !defined $sh->{password}) {
 	$sh->prompt_for_password();
@@ -857,7 +868,7 @@ sub do_edit {
     close(FH) || $sh->err("Can't write $tmp_file: $!\n", 1);
 
     my $command = "$sh->{editor} $tmp_file";
-    system($command) || print "Edit command '$command' failed ($?).\n";
+    system($command);
 
     # Read changes back in (editor may have deleted and rewritten file)
     open(FH, "<$tmp_file") || $sh->err("Can't open $tmp_file: $!\n");
@@ -889,6 +900,45 @@ sub do_type_info {
     $sh->sth_go($sth, 0);
 }
 
+sub do_describe {
+    my ($sh, $tab, @argv) = @_;
+	$sh->log( "Describle: $tab" );
+	my $dbh = $sh->{dbh};
+	my $sql = qq{select * from $tab where 1 = 0};
+	my $sth = $dbh->prepare( $sql );
+	$sth->execute;
+	my $cnt = $#{$sth->{NAME}};  #
+    	my @names = qw{NAME TYPE NULLABLE};
+	my @ti;
+	#push( @j, join( "\t", qw{NAME TYPE PRECISION SCALE NULLABLE}));
+	for ( my $c = 0; $c <= $cnt; $c++ ) {
+		push( my @j, $sth->{NAME}->[$c] || 0 );
+		my $m = $dbh->type_info($sth->{TYPE}->[$c]);
+		my $s;
+		if (ref $m eq 'HASH') {
+			$s = $m->{TYPE_NAME};
+		} elsif (not defined $m) {
+			 $s = q{undef } . $sth->{TYPE}->[$c];
+		} else {
+			warn "describe: can't parse data ($m) from type_info!";
+		}
+
+		if (defined $sth->{PRECISION}->[$c]) {
+			$s .= "(" . $sth->{PRECISION}->[$c] || '';
+			$s .= "," . $sth->{SCALE}->[$c] 
+			if ( defined $sth->{SCALE}->[$c] 
+				and $sth->{SCALE}->[$c] ne 0);
+			$s .= ")";
+		}
+		push(@j, $s,
+			 $sth->{NULLABLE}->[$c] ne 1? qq{N}: qq{Y} );
+		push(@ti,\@j);
+	}
+	$sth->finish;
+	$sth = $sh->prepare_from_data("describe", \@ti, \@names);
+	$sh->sth_go($sth, 0);
+}
+
 
 sub prepare_from_data {
     my ($sh, $statement, $data, $names, %attr) = @_;
@@ -917,17 +967,19 @@ sub do_option {
 	my ($opt_name, $value) = $opt =~ /^\s*(\w+)(?:=(.*))?/;
 	$opt_name = $options->{$opt_name} || $opt_name if $opt_name;
 	if (!$opt_name || !$sh->{options}->{$opt_name}) {
-	    $sh->log("Unknown or ambiguous option name '$opt_name'");
+	    $sh->log("Unknown or ambiguous option name '$opt_name' (use name=value format)");
 	    next;
 	}
 	my $crnt = (defined $sh->{$opt_name}) ? $sh->{$opt_name} : 'undef';
+	my $log;
 	if (not defined $value) {
-	    $sh->log("/option $opt_name=$crnt");
+	    $log = "$opt_name=$crnt";
 	}
 	else {
-	    $sh->log("/option $opt_name=$value  (was $crnt)");
+	    $log = "/option $opt_name=$value  (was $crnt)";
 	    $sh->{$opt_name} = ($value eq 'undef') ? undef : $value;
 	}
+	$sh->log($sh->{command_prefix}."option $log");
     }
 }
 
@@ -1110,7 +1162,7 @@ For this to be useful, turn the autocommit off. /option autocommit=0
 
   /trace              (set DBI trace level for current database)
 
-Adjust the trace level for DBI 0 - 4.  0 off.  4 lots of information.
+Adjust the trace level for DBI 0 - 4.  0 off.  4 is lots of information.
 Useful for determining what is really happening in DBI.  See DBI.
 
 =item type_info
